summaryrefslogtreecommitdiffstats
path: root/zebra/label_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'zebra/label_manager.h')
-rw-r--r--zebra/label_manager.h53
1 files changed, 27 insertions, 26 deletions
diff --git a/zebra/label_manager.h b/zebra/label_manager.h
index 4fee34d30..82154982c 100644
--- a/zebra/label_manager.h
+++ b/zebra/label_manager.h
@@ -40,19 +40,20 @@ extern "C" {
/*
* Label chunk struct
* Client daemon which the chunk belongs to can be identified by either
* proto (daemon protocol) + instance.
* If the client then passes a non-empty value to keep field when it requests
* for chunks, the chunks won't be garbage collected and the client will be
- * responsible of its release.
+ * responsible for releasing them.
* Otherwise, if the keep field is not set (value 0) for the chunk, it will be
* automatically released when the client disconnects or when it reconnects
* (in case it died unexpectedly, we can know it's the same because it will have
- * the same proto and instance values)
+ * the same proto+instance+session values)
*/
struct label_manager_chunk {
uint8_t proto;
unsigned short instance;
+ uint32_t session_id;
uint8_t keep;
uint32_t start; /* First label of the chunk */
uint32_t end; /* Last label of the chunk */
@@ -63,41 +64,40 @@ struct label_manager_chunk {
* so that any external module wanting to replace those can react
*/
-DECLARE_HOOK(lm_client_connect,
- (uint8_t proto, uint16_t instance, vrf_id_t vrf_id),
- (proto, instance, vrf_id));
-DECLARE_HOOK(lm_client_disconnect, (uint8_t proto, uint16_t instance),
- (proto, instance));
+DECLARE_HOOK(lm_client_connect, (struct zserv *client, vrf_id_t vrf_id),
+ (client, vrf_id));
+DECLARE_HOOK(lm_client_disconnect, (struct zserv *client), (client));
DECLARE_HOOK(lm_get_chunk,
- (struct label_manager_chunk * *lmc, uint8_t proto,
- uint16_t instance, uint8_t keep, uint32_t size, uint32_t base,
- vrf_id_t vrf_id),
- (lmc, proto, instance, keep, size, base, vrf_id));
+ (struct label_manager_chunk * *lmc, struct zserv *client,
+ uint8_t keep, uint32_t size, uint32_t base, vrf_id_t vrf_id),
+ (lmc, client, keep, size, base, vrf_id));
DECLARE_HOOK(lm_release_chunk,
- (uint8_t proto, uint16_t instance, uint32_t start, uint32_t end),
- (proto, instance, start, end));
+ (struct zserv *client, uint32_t start, uint32_t end),
+ (client, start, end));
DECLARE_HOOK(lm_cbs_inited, (), ());
/* declare wrappers to be called in zapi_msg.c (as hooks must be called in
* source file where they were defined)
*/
-void lm_client_connect_call(uint8_t proto, uint16_t instance, vrf_id_t vrf_id);
-void lm_get_chunk_call(struct label_manager_chunk **lmc, uint8_t proto,
- uint16_t instance, uint8_t keep, uint32_t size,
- uint32_t base, vrf_id_t vrf_id);
-void lm_release_chunk_call(uint8_t proto, uint16_t instance, uint32_t start,
+void lm_client_connect_call(struct zserv *client, vrf_id_t vrf_id);
+void lm_get_chunk_call(struct label_manager_chunk **lmc, struct zserv *client,
+ uint8_t keep, uint32_t size, uint32_t base,
+ vrf_id_t vrf_id);
+void lm_release_chunk_call(struct zserv *client, uint32_t start,
uint32_t end);
/* API for an external LM to return responses for requests */
int lm_client_connect_response(uint8_t proto, uint16_t instance,
- vrf_id_t vrf_id, uint8_t result);
-int lm_get_chunk_response(struct label_manager_chunk *lmc, uint8_t proto,
- uint16_t instance, vrf_id_t vrf_id);
+ uint32_t session_id, vrf_id_t vrf_id,
+ uint8_t result);
+int lm_get_chunk_response(struct label_manager_chunk *lmc, struct zserv *client,
+ vrf_id_t vrf_id);
/* convenience function to allocate an lmc to be consumed by the above API */
struct label_manager_chunk *create_label_chunk(uint8_t proto,
unsigned short instance,
+ uint32_t session_id,
uint8_t keep, uint32_t start,
uint32_t end);
void delete_label_chunk(void *val);
@@ -117,12 +117,13 @@ struct label_manager {
void label_manager_init(void);
struct label_manager_chunk *assign_label_chunk(uint8_t proto,
unsigned short instance,
+ uint32_t session_id,
uint8_t keep, uint32_t size,
uint32_t base);
-int release_label_chunk(uint8_t proto, unsigned short instance, uint32_t start,
- uint32_t end);
+int release_label_chunk(uint8_t proto, unsigned short instance,
+ uint32_t session_id, uint32_t start, uint32_t end);
int lm_client_disconnect_cb(struct zserv *client);
-int release_daemon_label_chunks(uint8_t proto, unsigned short instance);
+int release_daemon_label_chunks(struct zserv *client);
void label_manager_close(void);
#ifdef __cplusplus
@@ -40,19 +40,20 @@ extern "C" {
/*
* Label chunk struct
- * Client daemon which the chunk belongs to can be identified by either
- * proto (daemon protocol) + instance.
+ * Client daemon which the chunk belongs to can be identified by a tuple of:
+ * proto (daemon protocol) + instance + zapi session_id
* If the client then passes a non-empty value to keep field when it requests
* for chunks, the chunks won't be garbage collected and the client will be